Learn R Programming

sglOptim (version 1.3.8)

sgl.c.config: Featch information about the C side configuration of the package

Description

Featch information about the C side configuration of the package

Usage

sgl.c.config()

Arguments

Value

list